.. include:: ../README.rst

Simple usage
------------

.. literalinclude:: ../examples/echo_bot.py


Usage without dispatcher
------------------------

Just only interact with Bot API, without handling events

.. literalinclude:: ../examples/without_dispatcher.py


Contents
========

.. toctree::
    :maxdepth: 3

    install
    migration_2_to_3
    api/index
    dispatcher/index
    utils/index
    changelog
    contributing
